CropMode enum
How an asset is resized and cropped.
Values
- scale → const CropMode
-
Change dimensions without preserving aspect ratio.
- fit → const CropMode
-
Scale down to fit within the bounds.
- limit → const CropMode
-
Scale down only if larger than the bounds.
- mfit → const CropMode
-
Scale up only if smaller than the bounds.
- fill → const CropMode
-
Fill the bounds exactly, cropping the overflow.
- lfill → const CropMode
-
Fill the bounds, never scaling up.
- pad → const CropMode
-
Pad to the bounds after fitting.
- lpad → const CropMode
-
Pad only if smaller than the bounds.
- mpad → const CropMode
-
Pad after scaling up to fit.
- crop → const CropMode
-
Crop to the bounds without resizing.
- thumb → const CropMode
-
Create a thumbnail around detected content.
- fillPad → const CropMode
-
Fill the bounds using content-aware gravity.
- auto → const CropMode
-
Resize to the given aspect ratio using content-aware cropping.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireName → String
-
The value Cloudinary expects in a URL.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited